import { ContentView, ChildCursor, DOMPos } from "./contentview";
import { BlockView } from "./blockview";
import { CompositionView } from "./inlineview";
import { DecorationSet, WidgetType } from "./decoration";
import { Rect } from "./dom";
import { ViewUpdate, ScrollTarget } from "./extension";
import { EditorView } from "./editorview";
import { Direction } from "./bidi";
export declare class DocView extends ContentView {
    readonly view: EditorView;
    children: BlockView[];
    compositionDeco: DecorationSet;
    decorations: readonly DecorationSet[];
    dynamicDecorationMap: boolean[];
    minWidth: number;
    minWidthFrom: number;
    minWidthTo: number;
    impreciseAnchor: DOMPos | null;
    impreciseHead: DOMPos | null;
    forceSelection: boolean;
    dom: HTMLElement;
    lastUpdate: number;
    get length(): number;
    constructor(view: EditorView);
    update(update: ViewUpdate): boolean;
    private updateInner;
    private updateChildren;
    updateSelection(mustRead?: boolean, fromPointer?: boolean): void;
    enforceCursorAssoc(): void;
    nearest(dom: Node): ContentView | null;
    posFromDOM(node: Node, offset: number): number;
    domAtPos(pos: number): DOMPos;
    coordsAt(pos: number, side: number): Rect | null;
    measureVisibleLineHeights(viewport: {
        from: number;
        to: number;
    }): any[];
    textDirectionAt(pos: number): Direction;
    measureTextSize(): {
        lineHeight: number;
        charWidth: number;
        textHeight: number;
    };
    childCursor(pos?: number): ChildCursor;
    computeBlockGapDeco(): DecorationSet;
    updateDeco(): DecorationSet[];
    scrollIntoView(target: ScrollTarget): void;
    split: () => ContentView;
}
export declare function compositionSurroundingNode(view: EditorView): {
    from: number;
    to: number;
    node: Node;
    text: Text;
};
export declare class CompositionWidget extends WidgetType {
    readonly top: Node;
    readonly text: Text;
    readonly topView: ContentView | null;
    constructor(top: Node, text: Text, topView: ContentView | null);
    eq(other: CompositionWidget): boolean;
    toDOM(): HTMLElement;
    ignoreEvent(): boolean;
    get customView(): typeof CompositionView;
}
